@@ -1,12 +1,8 @@
 from cryptography.fernet import Fernet, InvalidToken
 from .exceptions import InvalidXsrfToken
-from os import environ
 import string
 import random
 
-def get_key() -> str | None:
-    return environ.get('ENCRYPTION_KEY')
-
 def create_xsrf(key: str) -> str:
     ft = Fernet(key)
     random_string = ''.join(random.choices(string.ascii_uppercase + string.digits, k=32))
